@@ -1,9 +1,10 @@
 library(sf)
 library(dplyr)
 
+old_tolerance <- testthat::testthat_tolerance()
+testthat::testthat_tolerance(5e-3) # relatively high tolerance for differences
 old_quiet <- getOption("quiet", default=0)
-NZ_buffer_Pac <- sf::st_transform(NZ_buffer30, crs=crs_Pacific)
-
+NZ_buffer30 <- hm_get_test("buffer")
 
 test_that("Using s2", {
   expect_true(sf_use_s2())
@@ -13,7 +14,7 @@ test_that("Grid creation", {
   options("quiet" = 0) #for no reporting
 
   # We project the in-built test maps
-  rg <- make_route_grid(NZ_buffer_Pac,"NZ lat-long at 500km",
+  rg <- make_route_grid(NZ_buffer30, "NZ lat-long at 500km",
                         target_km = 500, classify = TRUE,
                         lat_min = -49, lat_max = -32,
                         long_min = 162, long_max = 182)
@@ -32,7 +33,7 @@ test_that("Grid creation messaging", {
 
   options("quiet" = 1)
   # check messaging comes on - all the messages contain one of these words
-  expect_message(make_route_grid(NZ_buffer_Pac,"NZ lat-long at 300km",
+  expect_message(make_route_grid(NZ_buffer30, "NZ lat-long at 300km",
                                       target_km = 300, classify = TRUE,
                                       lat_min = -49, lat_max = -32,
                                       long_min = 162, long_max = 182),
@@ -42,3 +43,4 @@ test_that("Grid creation messaging", {
 
 
 options("quiet" = old_quiet)
+testthat::testthat_tolerance(old_tolerance)
